@@ -24,7 +24,6 @@ from collections import namedtuple
 import hypothesis.internal.distributions as dist
 from hypothesis.errors import BadTemplateDraw
 from hypothesis.control import assume
-from hypothesis.utils.show import show
 from hypothesis.utils.size import clamp
 from hypothesis.internal.compat import hrange, OrderedDict, integer_types
 from hypothesis.searchstrategy.strategies import BadData, check_type, \
@@ -35,7 +34,7 @@ from hypothesis.searchstrategy.strategies import BadData, check_type, \
 def safe_mul(x, y):
     result = x * y
     if result >= EFFECTIVELY_INFINITE:
-        return float(u'inf')
+        return float('inf')
     return result
 
 
@@ -52,7 +51,6 @@ class TupleStrategy(SearchStrategy):
                  strategies, tuple_type):
         SearchStrategy.__init__(self)
         strategies = tuple(strategies)
-        self.tuple_type = tuple_type
         self.element_strategies = strategies
         self.template_upper_bound = 1
         for e in self.element_strategies:
@@ -70,19 +68,16 @@ class TupleStrategy(SearchStrategy):
 
     def __repr__(self):
         if len(self.element_strategies) == 1:
-            tuple_string = u'%s,' % (repr(self.element_strategies[0]),)
+            tuple_string = '%s,' % (repr(self.element_strategies[0]),)
         else:
-            tuple_string = u', '.join(map(repr, self.element_strategies))
-        return u'TupleStrategy((%s), %s)' % (
-            tuple_string, self.tuple_type.__name__
+            tuple_string = ', '.join(map(repr, self.element_strategies))
+        return 'TupleStrategy((%s))' % (
+            tuple_string,
         )
 
     def newtuple(self, xs):
         """Produce a new tuple of the correct type."""
-        if self.tuple_type == tuple:
-            return tuple(xs)
-        else:
-            return self.tuple_type(*xs)
+        return tuple(xs)
 
     def draw_parameter(self, random):
         return tuple([
@@ -114,7 +109,7 @@ class TupleStrategy(SearchStrategy):
                 replacement[i] = s
                 yield tuple(replacement)
         accept.__name__ = str(
-            u'simplifier_for_index(%d, %s)' % (i, simplifier.__name__)
+            'simplifier_for_index(%d, %s)' % (i, simplifier.__name__)
         )
         return accept
 
@@ -153,12 +148,12 @@ class ListStrategy(SearchStrategy):
     """
 
     Parameter = namedtuple(
-        u'Parameter', (u'child_parameter', u'average_length')
+        'Parameter', ('child_parameter', 'average_length')
     )
 
     def __init__(
         self,
-        strategies, average_length=50.0, min_size=0, max_size=float(u'inf')
+        strategies, average_length=50.0, min_size=0, max_size=float('inf')
     ):
         SearchStrategy.__init__(self)
 
@@ -185,7 +180,7 @@ class ListStrategy(SearchStrategy):
 
     def __repr__(self):
         return (
-            u'ListStrategy(%r, min_size=%r, average_size=%r, max_size=%r)'
+            'ListStrategy(%r, min_size=%r, average_size=%r, max_size=%r)'
         ) % (
             self.element_strategy, self.min_size, self.average_length,
             self.max_size
@@ -256,7 +251,7 @@ class ListStrategy(SearchStrategy):
                 replacement[i] = s
                 yield tuple(replacement)
         accept.__name__ = str(
-            u'simplifier_for_index(%d, %s)' % (i, simplify.__name__)
+            'simplifier_for_index(%d, %s)' % (i, simplify.__name__)
         )
         return accept
 
@@ -406,7 +401,7 @@ class ListStrategy(SearchStrategy):
                         copy[i] = deepcopy(simpler)
                     yield tuple(copy)
         accept.__name__ = str(
-            u'shared_simplification(%s)' % (simplify.__name__,)
+            'shared_simplification(%s)' % (simplify.__name__,)
         )
         return accept
 
@@ -421,11 +416,11 @@ class ListStrategy(SearchStrategy):
         if self.element_strategy is None:
             return ()
         if len(value) < (self.min_size or 0):
-            raise BadData(u'List too short. len(%r)=%d < self.min_size=%d' % (
+            raise BadData('List too short. len(%r)=%d < self.min_size=%d' % (
                 value, len(value), self.min_size
             ))
         if len(value) > (self.max_size or len(value)):
-            raise BadData(u'List too long. len(%r)=%d > self.min_size=%d' % (
+            raise BadData('List too long. len(%r)=%d > self.min_size=%d' % (
                 value, len(value), self.max_size
             ))
         return tuple(map(self.element_strategy.from_basic, value))
@@ -499,9 +494,9 @@ class UniqueListTemplate(object):
 
     def __repr__(self):
         if self.values is not None:
-            return u'UniqueListTemplate(%d, %r)' % (self.size, self.values)
+            return 'UniqueListTemplate(%d, %r)' % (self.size, self.values)
         else:
-            return u'UniqueListTemplate(%d, ...)' % (self.size,)
+            return 'UniqueListTemplate(%d, ...)' % (self.size,)
 
     def __eq__(self, other):
         if not isinstance(other, UniqueListTemplate):
@@ -550,7 +545,7 @@ class UniqueListStrategy(SearchStrategy):
         self.elements.validate()
 
     Parameter = namedtuple(
-        u'Parameter', (u'parameter_seed', u'parameter')
+        'Parameter', ('parameter_seed', 'parameter')
     )
 
     def strictly_simpler(self, x, y):
@@ -579,7 +574,7 @@ class UniqueListStrategy(SearchStrategy):
     def draw_template(self, random, parameter):
         if self.min_size == self.max_size:
             size = self.min_size
-        elif self.max_size < float(u'inf'):
+        elif self.max_size < float('inf'):
             lower = math.floor(self.average_size)
             upper = math.ceil(self.average_size)
             mid_of_lower = (lower + self.min_size) / 2
@@ -691,7 +686,7 @@ class UniqueListStrategy(SearchStrategy):
                     template_seed=template.template_seed,
                     values=values
                 )
-        accept.__name__ = str(u'simplify_index(%d)' % (i,))
+        accept.__name__ = str('simplify_index(%d)' % (i,))
         return accept
 
     def reduce_size(self, random, template):
@@ -729,7 +724,7 @@ class UniqueListStrategy(SearchStrategy):
         check_data_type(integer_types, data[0])
         check_data_type(integer_types, data[1])
         if data[1] < self.min_size or data[1] > self.max_size:
-            raise BadData(u'Size %d out of range [%d, %r]' % (
+            raise BadData('Size %d out of range [%d, %r]' % (
                 data[1], self.min_size, self.max_size))
         if data[0] == 0:
             check_data_type(list, data[2])
@@ -740,7 +735,7 @@ class UniqueListStrategy(SearchStrategy):
             )
         else:
             if data[0] != 1:
-                raise BadData(u'Bad type tag %d' % (data[0],))
+                raise BadData('Bad type tag %d' % (data[0],))
             check_length(2, data[2])
             check_data_type(integer_types, data[2][0])
             check_data_type(integer_types, data[2][1])
@@ -774,7 +769,7 @@ class FixedKeysDictStrategy(MappedSearchStrategy):
                 ))
             except TypeError:
                 self.keys = tuple(sorted(
-                    strategy_dict.keys(), key=show,
+                    strategy_dict.keys(), key=repr,
                 ))
         super(FixedKeysDictStrategy, self).__init__(
             strategy=TupleStrategy(
@@ -783,7 +778,7 @@ class FixedKeysDictStrategy(MappedSearchStrategy):
         )
 
     def __repr__(self):
-        return u'FixedKeysDictStrategy(%r, %r)' % (
+        return 'FixedKeysDictStrategy(%r, %r)' % (
             self.keys, self.mapped_strategy)
 
     def pack(self, value):
