@@ -23,7 +23,8 @@ from collections import namedtuple
 
 import hypothesis.internal.distributions as dist
 from hypothesis.utils.size import clamp
-from hypothesis.internal.compat import hrange, text_type, integer_types
+from hypothesis.internal.compat import hrange, text_type, int_to_text, \
+    integer_types
 from hypothesis.searchstrategy.misc import SampledFromStrategy
 from hypothesis.searchstrategy.strategies import BadData, check_type, \
     infinitish, SearchStrategy, check_data_type, MappedSearchStrategy
@@ -34,7 +35,7 @@ def integer_or_bad(data):
     try:
         return int(data)
     except ValueError:
-        raise BadData(u'Invalid integer %r' % (data,))
+        raise BadData('Invalid integer %r' % (data,))
 
 
 class IntStrategy(SearchStrategy):
@@ -50,7 +51,7 @@ class IntStrategy(SearchStrategy):
         return integer_or_bad(data)
 
     def to_basic(self, template):
-        return text_type(template)
+        return int_to_text(template)
 
     def simplifiers(self, random, template):
         yield self.try_negate
@@ -101,7 +102,7 @@ class IntStrategy(SearchStrategy):
                     yield random.randint(lb + 1, new_lb - 1)
                 lb = new_lb
         accept.__name__ = str(
-            u'try_shrink(%d, %d)' % (lo, hi)
+            'try_shrink(%d, %d)' % (lo, hi)
         )
         return accept
 
@@ -114,7 +115,7 @@ class IntegersFromStrategy(SearchStrategy):
         self.average_size = average_size
 
     def __repr__(self):
-        return u'IntegersFromStrategy(%d)' % (self.lower_bound,)
+        return 'IntegersFromStrategy(%d)' % (self.lower_bound,)
 
     def draw_parameter(self, random):
         return clamp(
@@ -147,7 +148,7 @@ class IntegersFromStrategy(SearchStrategy):
                     yield random.randint(lb + 1, new_lb - 1)
                 lb = new_lb
         accept.__name__ = str(
-            u'try_shrink(%d, %d)' % (lo, hi)
+            'try_shrink(%d, %d)' % (lo, hi)
         )
         return accept
 
@@ -166,13 +167,13 @@ class IntegersFromStrategy(SearchStrategy):
     def from_basic(self, data):
         data = integer_or_bad(data)
         if data < 0:
-            raise BadData(u'Value %d out of range [0, infinity)' % (
+            raise BadData('Value %d out of range [0, infinity)' % (
                 data,
             ))
         return data
 
     def to_basic(self, template):
-        return text_type(template)
+        return int_to_text(template)
 
 
 class RandomGeometricIntStrategy(IntStrategy):
@@ -186,12 +187,12 @@ class RandomGeometricIntStrategy(IntStrategy):
 
     """
     Parameter = namedtuple(
-        u'Parameter',
-        (u'negative_probability', u'p')
+        'Parameter',
+        ('negative_probability', 'p')
     )
 
     def __repr__(self):
-        return u'RandomGeometricIntStrategy()'
+        return 'RandomGeometricIntStrategy()'
 
     def draw_parameter(self, random):
         return self.Parameter(
@@ -208,12 +209,12 @@ class RandomGeometricIntStrategy(IntStrategy):
 
 class WideRangeIntStrategy(IntStrategy):
     Parameter = namedtuple(
-        u'Parameter',
-        (u'center', u'width'),
+        'Parameter',
+        ('center', 'width'),
     )
 
     def __repr__(self):
-        return u'WideRangeIntStrategy()'
+        return 'WideRangeIntStrategy()'
 
     def draw_parameter(self, random):
         return self.Parameter(
@@ -237,11 +238,11 @@ class BoundedIntStrategy(SearchStrategy):
         self.start = start
         self.end = end
         if start > end:
-            raise ValueError(u'Invalid range [%d, %d]' % (start, end))
+            raise ValueError('Invalid range [%d, %d]' % (start, end))
         self.template_upper_bound = infinitish(end - start + 1)
 
     def __repr__(self):
-        return u'BoundedIntStrategy(%d, %d)' % (self.start, self.end)
+        return 'BoundedIntStrategy(%d, %d)' % (self.start, self.end)
 
     def strictly_simpler(self, x, y):
         return x < y
@@ -256,13 +257,13 @@ class BoundedIntStrategy(SearchStrategy):
     def from_basic(self, data):
         data = integer_or_bad(data)
         if data < self.start or data > self.end:
-            raise BadData(u'Value %d out of range [%d, %d]' % (
+            raise BadData('Value %d out of range [%d, %d]' % (
                 data, self.start, self.end
             ))
         return data
 
     def to_basic(self, template):
-        return text_type(template)
+        return int_to_text(template)
 
     def reify(self, value):
         return value
@@ -303,7 +304,7 @@ class FloatStrategy(SearchStrategy):
         self.int_strategy = RandomGeometricIntStrategy()
 
     def __repr__(self):
-        return u'%s()' % (self.__class__.__name__,)
+        return '%s()' % (self.__class__.__name__,)
 
     def strictly_simpler(self, x, y):
         if math.isnan(x):
@@ -366,8 +367,8 @@ class FloatStrategy(SearchStrategy):
     def simplify_weird_values(self, random, x):
         if math.isnan(x):
             yield 0.0
-            yield float(u'inf')
-            yield -float(u'inf')
+            yield float('inf')
+            yield -float('inf')
             return
         if math.isinf(x):
             yield math.copysign(
@@ -398,7 +399,7 @@ class FloatStrategy(SearchStrategy):
             for m in simplify(random, int(math.floor(x))):
                 yield float(m)
         accept.__name__ = str(
-            u'simplify_integral(%s)' % (simplify.__name__,)
+            'simplify_integral(%s)' % (simplify.__name__,)
         )
         return accept
 
@@ -425,7 +426,7 @@ class FloatStrategy(SearchStrategy):
                     break
                 yield y
 
-STANDARD_NAN = float(u'nan')
+STANDARD_NAN = float('nan')
 
 
 class WrapperFloatStrategy(FloatStrategy):
@@ -435,7 +436,7 @@ class WrapperFloatStrategy(FloatStrategy):
         self.sub_strategy = sub_strategy
 
     def __repr__(self):
-        return u'WrapperFloatStrategy(%r)' % (self.sub_strategy,)
+        return 'WrapperFloatStrategy(%r)' % (self.sub_strategy,)
 
     def draw_parameter(self, random):
         return self.sub_strategy.draw_parameter(random)
@@ -470,8 +471,8 @@ def compose_float(sign, exponent, fraction):
 class FullRangeFloats(FloatStrategy):
 
     Parameter = namedtuple(
-        u'Parameter',
-        (u'negative_probability', u'subnormal_probability')
+        'Parameter',
+        ('negative_probability', 'subnormal_probability')
     )
 
     def __init__(self, allow_nan=True, allow_infinity=True):
@@ -533,8 +534,8 @@ class FixedBoundedFloatStrategy(FloatStrategy):
 
     """
     Parameter = namedtuple(
-        u'Parameter',
-        (u'cut', u'leftwards')
+        'Parameter',
+        ('cut', 'leftwards')
     )
 
     def __init__(self, lower_bound, upper_bound):
@@ -544,7 +545,7 @@ class FixedBoundedFloatStrategy(FloatStrategy):
         assert upper_bound >= lower_bound
 
     def __repr__(self):
-        return u'FixedBoundedFloatStrategy(%s, %s)' % (
+        return 'FixedBoundedFloatStrategy(%s, %s)' % (
             self.lower_bound, self.upper_bound,
         )
 
@@ -582,9 +583,9 @@ class FixedBoundedFloatStrategy(FloatStrategy):
     def from_basic(self, data):
         result = super(FixedBoundedFloatStrategy, self).from_basic(data)
         if math.isnan(result):
-            raise BadData(u'NaN not allowed in range')
+            raise BadData('NaN not allowed in range')
         if result < self.lower_bound or result > self.upper_bound:
-            raise BadData(u'Value %f out of range [%f, %f]' % (
+            raise BadData('Value %f out of range [%f, %f]' % (
                 result, self.lower_bound, self.upper_bound
             ))
         return result
@@ -596,8 +597,8 @@ class BoundedFloatStrategy(FloatStrategy):
     the endpoints may be arbitrary."""
 
     Parameter = namedtuple(
-        u'Parameter',
-        (u'left', u'length', u'spread'),
+        'Parameter',
+        ('left', 'length', 'spread'),
     )
 
     def __init__(self):
@@ -643,8 +644,8 @@ class ExponentialFloatStrategy(FloatStrategy):
     """
 
     Parameter = namedtuple(
-        u'Parameter',
-        (u'lambd', u'zero_point', u'negative'),
+        'Parameter',
+        ('lambd', 'zero_point', 'negative'),
     )
 
     def draw_parameter(self, random):
@@ -674,12 +675,12 @@ class NastyFloats(SampledFromStrategy):
         ]
         if allow_infinity:
             elements.extend([
-                float(u'inf'),
-                -float(u'inf')
+                float('inf'),
+                -float('inf')
             ])
         if allow_nan:
             elements.extend([
-                float(u'nan')
+                float('nan')
             ])
 
         SampledFromStrategy.__init__(self, elements=elements)
@@ -692,7 +693,7 @@ class ComplexStrategy(MappedSearchStrategy):
     numbers."""
 
     def __repr__(self):
-        return u'ComplexStrategy()'
+        return 'ComplexStrategy()'
 
     def pack(self, value):
         return complex(*value)
